@@ -204,11 +204,12 @@ class AB_Base:
                     found_item = potential
                     break
             elif self.kwargs.get("search_complex", None) is not None:
+                self.logger.debug("Doing Complex Search".format(self.kwargs["search_complex"]))
                 all_passed = True
                 for k, v in self.kwargs["search_complex"].items():
                     compare_value = potential.get("k", None)
 
-                    if isinstance(compare_value, list()):
+                    if isinstance(compare_value, list):
                         self.logger.error("List Values can't be compared at this time.")
                         # TODO add in/only/not logic for lists
                         all_passed = False
